@@ -22,6 +22,8 @@ class SupermetricsToAzureSQL(Flow):
         fields: List[str],
         ds_segments: List[str] = None,
         date_range_type: str = None,
+        start_date: str = None,
+        end_date: str = None,
         settings: Dict[str, Any] = None,
         filter: str = None,
         max_rows: int = 1000000,
@@ -49,6 +51,8 @@ class SupermetricsToAzureSQL(Flow):
         self.ds_user = ds_user
         self.fields = fields
         self.date_range_type = date_range_type
+        self.start_date = start_date
+        self.end_date = end_date
         self.settings = settings
         self.filter = filter
         self.max_rows = max_rows
@@ -89,6 +93,8 @@ class SupermetricsToAzureSQL(Flow):
             ds_user=self.ds_user,
             fields=self.fields,
             date_range_type=self.date_range_type,
+            start_date=self.start_date,
+            end_date=self.end_date,
             settings=self.settings,
             filter=self.filter,
             max_rows=self.max_rows,
