@@ -2,6 +2,7 @@ from .azure_blob_storage import AzureBlobStorage
 from .azure_data_lake import AzureDataLake
 from .azure_sql import AzureSQL
 from .supermetrics import Supermetrics
-
+from .cloud_for_customers import CloudForCustomers
 # APIS
 from .uk_carbon_intensity import UKCarbonIntensity
+from .sqlite import SQLite
