@@ -38,3 +38,11 @@ class SQLite(SQL):
         conn_str = f"DRIVER={{{driver}}};SERVER={server};DATABASE={db_name};"
 
         return conn_str
+
+    def _check_if_table_exists(self, table: str, schema: str = None) -> bool:
+        fqn = f"{schema}.{table}" if schema is not None else table
+        exists_query = (
+            f"SELECT name FROM sqlite_master WHERE type='table' AND name='{fqn}'"
+        )
+        exists = bool(self.run(exists_query))
+        return exists
